@@ -71,90 +71,3 @@ sub _get_defaults {
 
 1;
 __END__
-
-=pod
-
-=head1 NAME
-
-ArangoDB::ConnectOptions - Connect option of ArangoDB 
-
-=head1 DESCRIPTION
-
-Connect options of ArangoDB.
-
-=head1 METHODS
-
-=head2 new($options)
-
-Constructor.
-$options is a connect option(Hash reference. The attributes of $options are:
-
-=over 4
-
-=item host
-
-Hostname or IP address of ArangoDB server.
-Default: localhost
-
-=item port
-
-Port number of ArangoDB server.
-Default: 8529
-
-=item timeout
-
-Seconds of HTTP connection timeout.
-
-=item keep_alive
-
-If it is true, use HTTP Keep-Alive connection.
-Default: false
-
-=item auth_type
-
-Authentication method.
-Supporting "Basic" only.
-
-=item auth_user
-
-User name for authentication
-
-=item auth_passwd
-
-Password for authentication
-
-=item proxy
-
-Proxy url for HTTP connection.
-
-=item inet_aton
-
-A callback function to customize name resolution. Takes two arguments: ($hostname, $timeout_in_seconds).
-
-See L<Furl::HTTP>.
-
-=back
-
-=head2 host()
-
-=head2 port()
-
-=head2 timeout()
-
-=head2 keep_alive()
-
-=head2 auth_type()
-
-=head2 auth_user()
-
-=head2 auth_passwd()
-
-=head2 proxy()
-
-=head2 inet_aton()
-
-=head1 AUTHOR
-
-Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
-
-=cut
